==> resource_planner-0.2.1.gem: config/initializers/assets.rb <==
# Be sure to restart your server when you modify this file.

# Add additional assets to the asset load path.
# Rails.application.config.assets.paths << Emoji.images_path
#Rails.application.config.assets.paths << ::ResourcePlanner::Engine.root.join('app','assets','resource_planner')
#Rails.application.config.assets.paths << ::ResourcePlanner::Engine.root.join('app','assets','fullcalendar-scheduler')
#Rails.application.config.assets.paths << ::ResourcePlanner::Engine.root.join('app','assets','bower-kendo-ui')

# Precompile additional assets.
# application.js, application.css, and all non-JS/CSS in the app/assets
# folder are already added.
# Rails.application.config.assets.precompile += %w( admin.js admin.css )

Rails.application.config.assets.precompile += %w( moment.css moment.js )
Rails.application.config.assets.precompile += %w( moment-timezone-with-data.min.js )
Rails.application.config.assets.precompile += %w( fullcalendar.css fullcalendar.js fullcalendar/locale-all.js )

Rails.application.config.assets.precompile += %w( fullcalendar-scheduler/scheduler.min.css fullcalendar-scheduler/scheduler.min.js )

Rails.application.config.assets.precompile += %w( jquery.dialogs.js )
Rails.application.config.assets.precompile += %w( jquery.doubleScroll.js )

Rails.application.config.assets.precompile += %w( resource_planner/reccuring_event_form.css resource_planner/reccuring_event_form.js )

Rails.application.config.assets.precompile += %w( resource_planner/index_fullcalendar.css resource_planner/index_fullcalendar.js )
Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar.css )
Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar_constructor.js )
Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar_timeline_manipulation.js )
Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar_highligherbar_manipulation.js )
Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar_resource_manipulation.js )

#Rails.application.config.assets.precompile += %w( kendo-ui-core/web/kendo.less )
#Rails.application.config.assets.precompile += %w( kendo-ui-core/kendo.common.core.less kendo-ui-core/web/kendo.default.less kendo-ui-core/web/kendo.default.mobile.less )
#Rails.application.config.assets.precompile += %w( kendo.all.min.js )
#Rails.application.config.assets.precompile += %w( kendo-ui-core/jquery.min.js kendo-ui-core/kendo.ui.core.js kendo-ui-core/kendo.calendar.js kendo-scheduler/kendo.scheduler.min.js )
#Rails.application.config.assets.precompile += %w( kendo-augurs/kendo.common-material.css kendo-augurs/kendo.material.min.css kendo-augurs/kendo.material.mobile.css )
#Rails.application.config.assets.precompile += %w( kendo-augurs/kendo.all.min.js kendo-augurs/kendo.timezones.min.js )

Rails.application.config.assets.precompile += %w( bower-kendo-ui/kendo.common.core.min.css bower-kendo-ui/kendo.default.min.css bower-kendo-ui/kendo.default.mobile.min.css )
Rails.application.config.assets.precompile += %w( bower-kendo-ui/kendo.common-material.min.css bower-kendo-ui/kendo.material.min.css bower-kendo-ui/kendo.material.mobile.min.css )
Rails.application.config.assets.precompile += %w( bower-kendo-ui/kendo.core.min.js )

#Rails.application.config.assets.precompile += %w( resource_planner/index_kendoui.css resource_planner/index_kendoui.js )
#Rails.application.config.assets.precompile += %w( resource_planner/form_kendoui.css resource_planner/form_kendoui.js )

==> resource_planner-0.2.9.gem: config/initializers/assets.rb <==
# Be sure to restart your server when you modify this file.

# Add additional assets to the asset load path.
# Rails.application.config.assets.paths << Emoji.images_path
#Rails.application.config.assets.paths << ::ResourcePlanner::Engine.root.join('app','assets','resource_planner')
#Rails.application.config.assets.paths << ::ResourcePlanner::Engine.root.join('app','assets','fullcalendar-scheduler')
#Rails.application.config.assets.paths << ::ResourcePlanner::Engine.root.join('app','assets','bower-kendo-ui')

# Precompile additional assets.
# application.js, application.css, and all non-JS/CSS in the app/assets
# folder are already added.
# Rails.application.config.assets.precompile += %w( admin.js admin.css )

Rails.application.config.assets.precompile += %w( moment.css moment.js )
Rails.application.config.assets.precompile += %w( moment-timezone-with-data.min.js )

Rails.application.config.assets.precompile += %w( fullcalendar/core/main.js )
Rails.application.config.assets.precompile += %w( fullcalendar/core/main.min.css fullcalendar/core/main.min.js fullcalendar/core//locales-all.min.js )
Rails.application.config.assets.precompile += %w( fullcalendar/daygrid/main.min.css fullcalendar/daygrid/main.min.js )
Rails.application.config.assets.precompile += %w( fullcalendar/timegrid/main.min.css fullcalendar/timegrid/main.min.js )
Rails.application.config.assets.precompile += %w( fullcalendar/list/main.min.css fullcalendar/list/main.min.js )
Rails.application.config.assets.precompile += %w( fullcalendar/interaction/main.min.js )
Rails.application.config.assets.precompile += %w( fullcalendar/rrule/main.min.js rrule/rrule.js )

Rails.application.config.assets.precompile += %w( fullcalendar-scheduler/timeline/main.min.css fullcalendar-scheduler/timeline/main.min.js )
Rails.application.config.assets.precompile += %w( fullcalendar-scheduler/resource-common/main.min.js )
Rails.application.config.assets.precompile += %w( fullcalendar-scheduler/resource-timeline/main.min.css fullcalendar-scheduler/resource-timeline/main.min.js )

Rails.application.config.assets.precompile += %w( jquery.dialogs.js )
Rails.application.config.assets.precompile += %w( jquery.doubleScroll.js )

Rails.application.config.assets.precompile += %w( resource_planner/reccuring_event_form.css resource_planner/reccuring_event_form.js )

Rails.application.config.assets.precompile += %w( resource_planner/index_fullcalendar.css resource_planner/index_fullcalendar.js )

Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar.css )
Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar_constructor.js )
Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar_timeline_manipulation.js )
Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar_highligherbar_manipulation.js )
Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar_resource_manipulation.js )

Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar_highlighterbar_tooltip.css )
Rails.application.config.assets.precompile += %w( resource_planner/form_fullcalendar_highlighterbar_tooltip.js )

#Rails.application.config.assets.precompile += %w( kendo-ui-core/web/kendo.less )
#Rails.application.config.assets.precompile += %w( kendo-ui-core/kendo.common.core.less kendo-ui-core/web/kendo.default.less kendo-ui-core/web/kendo.default.mobile.less )
#Rails.application.config.assets.precompile += %w( kendo.all.min.js )
#Rails.application.config.assets.precompile += %w( kendo-ui-core/jquery.min.js kendo-ui-core/kendo.ui.core.js kendo-ui-core/kendo.calendar.js kendo-scheduler/kendo.scheduler.min.js )
#Rails.application.config.assets.precompile += %w( kendo-augurs/kendo.common-material.css kendo-augurs/kendo.material.min.css kendo-augurs/kendo.material.mobile.css )
#Rails.application.config.assets.precompile += %w( kendo-augurs/kendo.all.min.js kendo-augurs/kendo.timezones.min.js )

Rails.application.config.assets.precompile += %w( bower-kendo-ui/kendo.common.core.min.css bower-kendo-ui/kendo.default.min.css bower-kendo-ui/kendo.default.mobile.min.css )
Rails.application.config.assets.precompile += %w( bower-kendo-ui/kendo.common-material.min.css bower-kendo-ui/kendo.material.min.css bower-kendo-ui/kendo.material.mobile.min.css )
Rails.application.config.assets.precompile += %w( bower-kendo-ui/kendo.core.min.js )

#Rails.application.config.assets.precompile += %w( resource_planner/index_kendoui.css resource_planner/index_kendoui.js )
#Rails.application.config.assets.precompile += %w( resource_planner/form_kendoui.css resource_planner/form_kendoui.js )
